==> computer_use_ootb_internal-0.0.182.tar.gz: computer_use_ootb_internal-0.0.182/src/computer_use_ootb_internal/preparation/word_prepare.py <==
import os
import platform
import subprocess
import logging
from pathlib import Path
import time

log = logging.getLogger(__name__)

def run_preparation(state):
    """
    Performs environment preparation specific to Word on Windows.
    Opens a specific template file located on the user's desktop and maximizes the window.
    Kills existing Word processes first.
    """
    if platform.system() != "Windows":
        log.warning("Word preparation skipped: Not running on Windows.")
        return

    log.info(f"Word preparation: Starting on Windows platform...")

    try:
        # Determine the desktop path for Windows
        try:
            username = os.environ.get("USERNAME", "")
            if not username:
                log.error("Could not determine Windows username from environment")
                return
            
            log.info(f"Using Windows username: {username}")
            desktop_path = Path(f"C:/Users/{username}/Desktop")
            
            if not desktop_path.exists():
                log.error(f"Desktop path not found at: {desktop_path}")
                alt_path = Path(f"C:/Documents and Settings/{username}/Desktop")
                if alt_path.exists():
                    desktop_path = alt_path
                    log.info(f"Using alternative desktop path: {desktop_path}")
                else:
                    log.error("Failed to find user's desktop directory")
                    return
            
        except Exception as e:
            log.error(f"Error determining Windows user desktop: {e}", exc_info=True)
            return
            
        # Construct path to template file
        template_file = desktop_path / "template.docx" # Changed extension
        log.info(f"Looking for template file at: {template_file}")

        if not template_file.exists():
            log.error(f"Template file not found at: {template_file}")
            return

        # --- Kill existing Word processes --- 
        log.info("Attempting to close existing Microsoft Word processes...")
        try:
            # Command to forcefully terminate Word processes by image name
            kill_cmd = ['taskkill', '/F', '/IM', 'WINWORD.EXE'] # Changed process name
            kill_result = subprocess.run(kill_cmd,
                                       capture_output=True, text=True, check=False)
            
            # Check taskkill result
            if kill_result.returncode == 0:
                log.info("Successfully sent termination signal to WINWORD.EXE processes.")
            elif "not found" in kill_result.stderr.lower() or "not found" in kill_result.stdout.lower():
                 log.info("No running WINWORD.EXE processes found to close.")
            else:
                 log.warning(f"taskkill command finished with return code {kill_result.returncode}. Output: {kill_result.stdout} Stderr: {kill_result.stderr}")
            time.sleep(2) 
        except FileNotFoundError:
            log.error("Error: 'taskkill' command not found. Make sure it's in the system PATH.")
        except Exception as e:
            log.error(f"Error occurred while trying to close Word: {e}", exc_info=True)
        # --- End of kill process --- 

        # Open the file with Word maximized on Windows
        log.info(f"Attempting to open {template_file} with Word maximized on Windows...")
        try:
            # Use start command with /max flag on Windows
            cmd = ['cmd', '/c', 'start', '/max', 'winword', str(template_file)] # Changed app name
            # Temporarily commented out file opening
            # result = subprocess.run(cmd, check=False, capture_output=True, text=True)
            log.info(f"(Skipped) Would open file with command: {' '.join(cmd)}")
            result = None # Set result to None or mock success if needed elsewhere
            
            # if result and result.returncode == 0:
            #     log.info(f"Successfully launched Word maximized with {template_file}")
            # else:
            #     log.error(f"Error opening Word: {result.stderr.strip() if result else 'Command not run'}")
            #     if result and result.stdout:
            #         log.error(f"Stdout from start command: {result.stdout.strip()}")
        except FileNotFoundError:
             log.error("Error: 'cmd' or 'start' command not found. Ensure system PATH is configured correctly.")
        except Exception as e:
            log.error(f"Exception opening Word on Windows: {e}", exc_info=True)
                
    except Exception as e:
        log.error(f"An unexpected error occurred during Word preparation: {e}", exc_info=True)

==> computer_use_ootb_internal-0.0.184.tar.gz: computer_use_ootb_internal-0.0.184/src/computer_use_ootb_internal/preparation/word_prepare.py <==
import os
import platform
import subprocess
import logging
from pathlib import Path
import time

log = logging.getLogger(__name__)

def run_preparation(state):
    """
    Performs environment preparation specific to Word on Windows.
    Opens a specific template file located on the user's desktop and maximizes the window.
    Kills existing Word processes first.
    """
    if platform.system() != "Windows":
        log.warning("Word preparation skipped: Not running on Windows.")
        return

    log.info(f"Word preparation: Starting on Windows platform...")

    try:
        # Determine the desktop path for Windows
        try:
            username = os.environ.get("USERNAME", "")
            if not username:
                log.error("Could not determine Windows username from environment")
                return
            
            log.info(f"Using Windows username: {username}")
            desktop_path = Path(f"C:/Users/{username}/Desktop")
            
            if not desktop_path.exists():
                log.error(f"Desktop path not found at: {desktop_path}")
                alt_path = Path(f"C:/Documents and Settings/{username}/Desktop")
                if alt_path.exists():
                    desktop_path = alt_path
                    log.info(f"Using alternative desktop path: {desktop_path}")
                else:
                    log.error("Failed to find user's desktop directory")
                    return
            
        except Exception as e:
            log.error(f"Error determining Windows user desktop: {e}", exc_info=True)
            return
            
        # Construct path to template file
        template_file = desktop_path / "template.docx" # Changed extension
        log.info(f"Looking for template file at: {template_file}")

        if not template_file.exists():
            log.error(f"Template file not found at: {template_file}")
            return

        # --- Kill existing Word processes --- 
        log.info("Attempting to close existing Microsoft Word processes...")
        try:
            # Command to forcefully terminate Word processes by image name
            kill_cmd = ['taskkill', '/F', '/IM', 'WINWORD.EXE'] # Changed process name
            kill_result = subprocess.run(kill_cmd,
                                       capture_output=True, text=True, check=False)
            
            # Check taskkill result
            if kill_result.returncode == 0:
                log.info("Successfully sent termination signal to WINWORD.EXE processes.")
            elif "not found" in kill_result.stderr.lower() or "not found" in kill_result.stdout.lower():
                 log.info("No running WINWORD.EXE processes found to close.")
            else:
                 log.warning(f"taskkill command finished with return code {kill_result.returncode}. Output: {kill_result.stdout} Stderr: {kill_result.stderr}")
            time.sleep(2) 
        except FileNotFoundError:
            log.error("Error: 'taskkill' command not found. Make sure it's in the system PATH.")
        except Exception as e:
            log.error(f"Error occurred while trying to close Word: {e}", exc_info=True)
        # --- End of kill process --- 

        # Open the file with Word maximized on Windows
        try:
            # Check if template exists and construct command accordingly
            if template_file.exists():
                log.info(f"Template file found. Attempting to open {template_file} with Word maximized...")
                cmd = ['cmd', '/c', 'start', '/max', 'winword', str(template_file)]
            else:
                log.info(f"Template file not found. Attempting to launch Word maximized...")
                cmd = ['cmd', '/c', 'start', '/max', 'winword']

            log.info(f"Executing command: {' '.join(cmd)}")
            result = subprocess.run(cmd, check=False, capture_output=True, text=True, creationflags=subprocess.CREATE_NO_WINDOW) # Add CREATE_NO_WINDOW
            
            if result.returncode == 0:
                log.info(f"Successfully executed command for Word.")
            else:
                log.error(f"Error opening Word: {result.stderr.strip()}")
                if result.stdout:
                    log.error(f"Stdout from start command: {result.stdout.strip()}")
        except FileNotFoundError:
             log.error("Error: 'cmd' or 'start' command not found. Ensure system PATH is configured correctly.")
        except Exception as e:
            log.error(f"Exception opening Word on Windows: {e}", exc_info=True)
                
    except Exception as e:
        log.error(f"An unexpected error occurred during Word preparation: {e}", exc_info=True)
